@@ -494,17 +494,17 @@ def examples_bxReposBaseDirsFull():
 
     cmndName = "pbdUpdate" ; cmndArgs = "all" ;
     cps = collections.OrderedDict() ; cps['baseDir'] = '/bisos/git/anon/bxRepos';
-    cps['pbdName'] = 'bxReposRoot' ; cps['vcMode'] = 'anon'
+    cps['pbdName'] = 'bxReposRoot' ; cps['vcMode'] = 'anon' ; cps['gitLabel'] = 'github.com'
     icm.ex_gCmndMenuItem(cmndName, cps, cmndArgs, verbosity='little')
 
     cmndName = "pbdUpdate" ; cmndArgs = "all" ;
     cps = collections.OrderedDict() ; cps['baseDir'] = '/bisos/git/auth/bxRepos';
-    cps['pbdName'] = 'bxReposRoot' ; cps['vcMode'] = 'auth'
+    cps['pbdName'] = 'bxReposRoot' ; cps['vcMode'] = 'auth' ; cps['gitLabel'] = 'github.com'
     icm.ex_gCmndMenuItem(cmndName, cps, cmndArgs, verbosity='little')
 
     cmndName = "pbdUpdate" ; cmndArgs = "all" ;
     cps = collections.OrderedDict(); cps['baseDir'] = '/bisos/git/anon/ext';
-    cps['pbdName'] = 'extRepos' ; cps['vcMode'] = 'anon'
+    cps['pbdName'] = 'extRepos' ; cps['vcMode'] = 'anon' ; cps['gitLabel'] = 'github.com'
     icm.ex_gCmndMenuItem(cmndName, cps, cmndArgs, verbosity='little')
 
     
@@ -1054,6 +1054,9 @@ def pbdDict_bxReposRoot(
     gitClone('blee-binders/bxde-model',  'blee-binders/bxde-model', vcMode)
     gitClone('blee-binders/bxde-dev',  'blee-binders/bxde-dev', vcMode)
     gitClone('blee-binders/bisos-apps',  'blee-binders/bisos-apps', vcMode)
+    gitClone('blee-binders/bisos-svcs',  'blee-binders/bisos-svcs', vcMode)
+    gitClone('blee-binders/connectivity',  'blee-binders/connectivity', vcMode)
+    gitClone('blee-binders/desktop',  'blee-binders/desktop', vcMode)
     gitClone('blee-binders/bisos-periphery',  'blee-binders/bisos-periphery', vcMode)
     gitClone('blee-binders/espoused',  'blee-binders/espoused', vcMode)
     gitClone('blee-binders/non-libre-halaal',  'blee-binders/non-libre-halaal', vcMode)
